package com.rthoni.camotion.ui;

import android.app.Fragment;
import android.os.Bundle;
import android.view.SubMenu;
import android.support.design.widget.NavigationView;
import android.support.v4.view.GravityCompat;
import android.support.v4.widget.DrawerLayout;
import android.support.v7.app.ActionBarDrawerToggle;
import android.support.v7.app.AppCompatActivity;
import android.support.v7.widget.Toolbar;
import android.view.MenuItem;
import android.widget.TextView;

import com.luticate.auth.dbo.LuFullLoginDbo;
import com.rthoni.camotion.R;
import com.rthoni.camotion.business.CamotionBusiness;
import com.rthoni.camotion.dbo.LocationDbo;
import com.rthoni.camotion.ui.fragments.CamerasFragment;

import java.util.List;

public class MainActivity extends AppCompatActivity
        implements NavigationView.OnNavigationItemSelectedListener {

    private LuFullLoginDbo _fullLoginDbo = null;
    private LocationDbo _currentLocation = null;
    private TextView _locationNameView;
    private SubMenu _locationsMenu;
    private NavigationView _navigationView;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);
        Toolbar toolbar = (Toolbar) findViewById(R.id.toolbar);
        setSupportActionBar(toolbar);

        _locationNameView = (TextView) findViewById(R.id.location_name_textview);

        DrawerLayout drawer = (DrawerLayout) findViewById(R.id.drawer_layout);
        ActionBarDrawerToggle toggle = new ActionBarDrawerToggle(this, drawer, toolbar,
                R.string.navigation_drawer_open, R.string.navigation_drawer_close);
        drawer.setDrawerListener(toggle);
        toggle.syncState();

        _navigationView = (NavigationView) findViewById(R.id.nav_view);
        _navigationView.setNavigationItemSelectedListener(this);
        _locationsMenu = _navigationView.getMenu().findItem(R.id.location_menu).getSubMenu();

        init();
    }

    private void init()
    {
        List<LocationDbo> locations = CamotionBusiness.getLocations(MainActivity.this);
        _locationsMenu.clear();
        if (locations.isEmpty()) {
            return;
        }
        for (final LocationDbo location : locations) {
            MenuItem item = _locationsMenu.add(location.getName());
            item.setIcon(R.mipmap.ic_location);
            item.setOnMenuItemClickListener(new MenuItem.OnMenuItemClickListener() {
                @Override
                public boolean onMenuItemClick(MenuItem item) {
                    setLocation(location);
                    return false;
                }
            });
        }
        // Force drawer update; need a fix
        MenuItem item = _navigationView.getMenu().add("test42");
        _navigationView.getMenu().removeItem(item.getItemId());
        setLocation(locations.get(0));
    }

    private void setLocation(LocationDbo location)
    {
        _currentLocation = location;
        _locationNameView.setText(_currentLocation.getName());
        showView(R.id.nav_cameras);
    }

    private void showView(int view)
    {
        Fragment fragment = null;
        if (view == R.id.nav_cameras) {
            fragment = new CamerasFragment();
        }
        getFragmentManager().beginTransaction().replace(R.id.container, fragment).commit();
    }

    @Override
    public void onBackPressed() {
        DrawerLayout drawer = (DrawerLayout) findViewById(R.id.drawer_layout);
        if (drawer.isDrawerOpen(GravityCompat.START)) {
            drawer.closeDrawer(GravityCompat.START);
        } else {
            super.onBackPressed();
        }
    }

    @SuppressWarnings("StatementWithEmptyBody")
    @Override
    public boolean onNavigationItemSelected(MenuItem item) {
        int id = item.getItemId();

        if (id == R.id.nav_cameras) {
            showView(id);
        } else if (id == R.id.nav_sensors) {
            showView(id);
        } else if (id == R.id.nav_commands) {
            showView(id);
        }

        DrawerLayout drawer = (DrawerLayout) findViewById(R.id.drawer_layout);
        drawer.closeDrawer(GravityCompat.START);
        return true;
    }
}
