package com.luticate.utils.business;

import com.loopj.android.http.AsyncHttpClient;
import com.loopj.android.http.JsonHttpResponseHandler;
import com.loopj.android.http.RequestParams;
import com.luticate.utils.dbo.LuDbo;

import org.json.JSONObject;

import java.util.HashMap;

import cz.msebera.android.httpclient.Header;

/**
 *
 * Created by robin on 11/27/15.
 */
public class LuRequest {

    private static AsyncHttpClient client = new AsyncHttpClient();

    protected static <T extends LuDbo> JsonHttpResponseHandler getHandler(final Class<T> type, final LuPromise<T> promise)
    {
        return new JsonHttpResponseHandler()
        {
            @Override
            public void onSuccess(int statusCode, Header[] headers, JSONObject response) {
                try {
                    T dbo = type.newInstance();
                    try {
                        dbo.fromJson(response.getJSONObject("Data"));
                        promise.resolve(dbo);
                    } catch (Exception e)
                    {
                        e.printStackTrace();
                        promise.reject(new LuPromise.LuPromiseError("Failed to parse success server response", statusCode));
                    }
                } catch (Exception e) {
                    e.printStackTrace();
                    promise.reject(new LuPromise.LuPromiseError("Failed to initialize server response", statusCode));
                }
            }

            @Override
            public void onFailure(int statusCode, Header[] headers, Throwable throwable, JSONObject errorResponse) {
                try {
                    promise.reject(new LuPromise.LuPromiseError(errorResponse.getString("Message"), statusCode));
                } catch (Exception e) {
                    e.printStackTrace();
                    promise.reject(new LuPromise.LuPromiseError("Failed to parse error server response", statusCode));
                }
            }
        };
    }

    public static <T extends LuDbo> LuPromise<T> get(Class<T> type, String url, HashMap<String, String> getParams)
    {
        LuPromise<T> promise = new LuPromise<>();
        client.get(url, new RequestParams(getParams), getHandler(type, promise));
        return promise;
    }

    public static <T extends LuDbo> LuPromise<T> get(Class<T> type, String url)
    {
        return get(type, url, new HashMap<String, String>());
    }

    public static <T extends LuDbo> LuPromise<T> post(Class<T> type, String url, HashMap<String, String> postParams)
    {
        LuPromise<T> promise = new LuPromise<>();
        client.post(url, new RequestParams(postParams), getHandler(type, promise));
        return promise;
    }

    public static <T extends LuDbo> LuPromise<T> post(Class<T> type, String url)
    {
        return post(type, url, new HashMap<String, String>());
    }
}
